pub struct Cache { /* private fields */ }Implementations
Sourceimpl Cache
impl Cache
Sourcepub fn with_huggingface_token(self, token: Option<String>) -> Self
pub fn with_huggingface_token(self, token: Option<String>) -> Self
Set the Hugging Face token to use for downloading (defaults to the token set with huggingface-cli login, and then the environment variable HF_TOKEN)
Sourcepub fn exists(&self, source: &FileSource) -> bool
pub fn exists(&self, source: &FileSource) -> bool
Check if the file exists locally (if it is a local file or if it has been downloaded)
Sourcepub async fn get(
&self,
source: &FileSource,
progress: impl FnMut(FileLoadingProgress),
) -> Result<PathBuf, CacheError>
pub async fn get( &self, source: &FileSource, progress: impl FnMut(FileLoadingProgress), ) -> Result<PathBuf, CacheError>
Get the file from the cache, downloading it if necessary